GriteContext

Struct GriteContext 

pub struct GriteContext {
    pub git_dir: PathBuf,
    pub actor_id: String,
    pub actor_config: ActorConfig,
    pub data_dir: PathBuf,
    pub source: ActorSource,
}
Resolved context for a grite command

Fields

git_dir: PathBufactor_id: Stringactor_config: ActorConfigdata_dir: PathBufsource: ActorSource

Implementations

Source

impl GriteContext

pub fn find_git_dir() -> Result<PathBuf, GriteError>

Find the shared git directory (commondir) for this repository.

pub fn find_git_dir_at(path: impl AsRef<Path>) -> Result<PathBuf, GriteError>

pub fn resolve(opts: &ResolveOptions) -> Result<Self, GriteError>

Resolve the actor context from options.

pub fn open_store(&self) -> Result<LockedStore, GriteError>

Open the store for this context with exclusive filesystem lock.

pub fn sled_path(&self) -> PathBuf

Get the sled database path

pub fn open_wal(&self) -> Result<WalManager, GitError>

Open the WAL manager

pub fn open_snapshot(&self) -> Result<SnapshotManager, GitError>

Open the snapshot manager

pub fn open_sync(&self) -> Result<SyncManager, GitError>

Open the sync manager

pub fn open_lock_manager(&self) -> Result<LockManager, GitError>

Open the lock manager

pub fn get_lock_policy(&self) -> LockPolicy

Get the lock policy from repo config

pub fn check_lock(&self, resource: &str) -> Result<LockCheckResult, GriteError>

Check locks for a resource before a write operation

pub fn repo_root(&self) -> PathBuf

Get the repository root path

pub fn load_signing_key(&self) -> Option<SigningKeyPair>

Load the signing key pair for this actor (if available)

pub fn sign_event(&self, event: Event) -> Event

Sign an event if a signing key is available

pub fn execution_mode(&self, no_daemon: bool) -> ExecutionMode

Determine execution mode (local vs daemon)