Module event_helper

Module event_helper 

Helper for inserting events into both sled store and Git WAL

Structs

InsertResult
Result of inserting an event

Functions

append_to_wal
Try to append to WAL without inserting to store Useful for batch operations or when store is already updated
insert_and_append
Insert an event into both the sled store and the Git WAL